kerasadf.layers.pooling.AveragePooling1D
========================================

.. currentmodule:: kerasadf.layers.pooling

.. autoclass:: AveragePooling1D
   :members:
   :undoc-members:
   :no-inherited-members:
   :show-inheritance:
